@@ -14,10 +14,8 @@ use List::MoreUtils qw(uniq);
 use List::AllUtils qw(sum);
 use Statistics::Basic qw(:all);
 use Set::Intersection;
-#$Data::Dumper::Indent = 0;
-#$Data::Dumper::Useqq  = 1;
-#$Data::Dumper::Terse  = 1;
 use Data::Dump qw(dump);
+use Data::Dumper;
 use feature 'say';
 use Sim::OPT;
 use Sim::OPT::Morph;
@@ -25,10 +23,12 @@ use Sim::OPT::Sim;
 use Sim::OPT::Report;
 use Sim::OPT::Takechance;
 
+$Data::Dumper::Indent = 0;
+$Data::Dumper::Useqq  = 1;
+$Data::Dumper::Terse  = 1;
 
 no strict; 
 no warnings;
-use warnings::unused;
 
 @ISA = qw(Exporter); # our @adamkISA = qw(Exporter);
 #%EXPORT_TAGS = ( DEFAULT => [qw( &opt &prepare )]); # our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
@@ -516,7 +516,7 @@ sub descend
 		
 		my @winnerelms = split(/\s+|,/, $winnerentry);
 		my $winnerline = $winnerelms[0]; 
-		my $winnerval = $winnerelms[$#winnerelms];
+		my $winnerval = $winnerelms[-1];
 		push ( @{ $uplift[$countcase][$countblock] }, $winnerval); 
 		
 		my $message;
@@ -568,9 +568,8 @@ sub descend
 		#}
 		
 		push( @backvalues, [ $winnerline, $winnerval ] );  say $tee "OBTAINED--->\@backvalues " . dump( @backvalues );
-		push( @{ $datastruc{$word} }, $winnerline );  say $tee "OBTAINED--->\@{ \$datastruc{\$word} } " . dump( @{ $datastruc{$word} } );
+		push( @{ $datastruc{$word} }, $winnerentry );  say $tee "OBTAINED--->\@{ \$datastruc{\$word} } " . dump( @{ $datastruc{$word} } );
 		say $tee "\$sourcesweeps[ \$countcase ][ \$countblock ][0] " . dump( $sourcesweeps[ $countcase ][ $countblock ][0] );
-				
 		
 		if ( ( not ( defined( $openingelt ) ) ) and ( not ( defined( $closingelt ) ) ) )
 		{	#say $tee "SETTING UP THINGS FOR GAUSS-SEIDEL METHOD (SEQUENTIAL)";
@@ -609,8 +608,6 @@ sub descend
 		}
 		elsif ( defined( $closingelt ) )
 		{
-			#say $tee "SETTING UP THINGS FOR JACOBI - PARALLEL - METHOD";
-			
 			foreach my $values_ref ( @backvalues )
 			{
 				my $key = $values_ref->[0];
